@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 
-from .client import FlatQubeClient, FlatQubeClientError, CurrencySortOptions, CurrencySortOrders
+from .client import FlatQubeClient, FlatQubeClientError, SortOrder, CurrencySortBy
 from .models import CurrencyInfo, FarmingPoolInfo
 
 from .version import __version__  # noqa
@@ -9,8 +9,8 @@ from .version import __version__  # noqa
 __all__ = [
     'FlatQubeClient',
     'FlatQubeClientError',
-    'CurrencySortOptions',
-    'CurrencySortOrders',
+    'SortOrder',
+    'CurrencySortBy',
     'CurrencyInfo',
     'FarmingPoolInfo',
 ]
